@@ -14,6 +14,8 @@ import os.path
 
 ROOT = os.path.normpath(os.path.join(os.path.dirname(__file__), os.pardir))
 
+MODULE_ROOT = os.path.dirname(__import__('sentry').__file__)
+
 # Allow local testing of Sentry even if DEBUG is enabled
 DEBUG = False
 
@@ -43,7 +45,7 @@ URL_PREFIX = ''
 # Allow access to Sentry without authentication.
 PUBLIC = False
 
-EMAIL_SUBJECT_PREFIX = ''
+EMAIL_SUBJECT_PREFIX = '[Sentry] '
 
 INTERNAL_IPS = set()
 
