@@ -80,8 +80,10 @@ TEMPLATE_LOADERS = (
 MIDDLEWARE_CLASSES = (
     'django.middleware.common.CommonMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.middleware.locale.LocaleMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'sentry.middleware.SentryMiddleware',
     # 'django.contrib.messages.middleware.MessageMiddleware',
 )
 
@@ -119,6 +121,8 @@ ADMIN_MEDIA_PREFIX = '/_admin_media/'
 SENTRY_PUBLIC = True
 SENTRY_PROJECT = 1
 
+EMAIL_SUBJECT_PREFIX = '[Sentry] '
+
 # Configure logging
 from raven.conf import setup_logging
 from raven.contrib.django.handlers import SentryHandler
